/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2010 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package org.pz.platypus;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

/**
 * Reads files consisting of lines of text, one line at a time. All standard I/O handled here.
 * Used for reading config and resource files.
 *
 * @author alb
 */
public class TextFileReader
{
    private String filename;
    private BufferedReader reader;
    private boolean trimWhitespace;

    /**
     * Create an instance of org.pz.platypus.TextFileReader to read the specified file
     *
     * @param fileName name of the file to read
     * @throws IllegalArgumentException if filename is null
     */
    public TextFileReader( final String fileName )
    {
        if( fileName == null ) {
            throw new IllegalArgumentException();
        }

        filename = fileName;
    }

    /**
     * opens the reader for the indicated file
     *
     * @throws FileNotFoundException if the file specified by filename does not exist.
     */
    public void open() throws FileNotFoundException
    {
        reader = new BufferedReader( new FileReader( filename ));
    }

    /**
     * Reads a line, optionally trims trailing whitespace, and returns it
     *
     * @return the line of text. Null at EOF.
     * @throws IOException if an error occurs reading the file
     */
    public String retrieveNextLine() throws IOException
    {
        String line = reader.readLine();

        // at EOF
        if( line == null ) {
            return( null );
        }

        if( trimWhitespace ) {
            return( line.trim() );
        }

        return( line );
    }

    /**
     * Set whether the reader should trim whitespace on lines read in
     *
     * @param yesNo
     */
    public void setTrimWhiteSpace( final boolean yesNo )
    {
        trimWhitespace = yesNo;
    }
}
